
# Activities
	Change of names: 'production of' -> 'Growing of'/'Raising of'/'Slaughtering of'
A_VOIL Renamed to A_Othvoils
A_OBUS moved from ai_82 to ai_74
A_Cocod	Moved from agriculture to manufacturing
A_Bufmilk	Moved from manufacturing to agriculture
A_Bufmilk	Moved from manufacturing to agriculture
A_Shemilk	Moved from manufacturing to agriculture
A_Goamilk	Moved from manufacturing to agriculture
A_MILK	Moved from manufacturing to agriculture
A_WOOL	Redefined to 'Raising of sheep for wool'
A_Silk_ree	Added to represent 'Raising of silk-worms for cocoon'
ai_0891	Code replaced by 'A_CHMF'
A_PCAT	Removed
A_PPIG	Removed
A_PPLT	Removed
ai_1071	Subcategories added
ai_1073	Added
A_Chocs	Added
A_Candy	Added
ai_1079	Subcategories added
ai_2013 Added as parent of A_PLAS
A_RUB	Added as sibling of A_PLAS
ai_2397	Added
ai_28151	Added
ai_4540	Replaced by ai_4541 (Sale) and ai_4542 (maintenance)
at_39	Added
A_ELMA	TODO: Moved from ai_261 to ai_27
ai_0111_40	Renamed to ai_0112
ai_0113_29	Renamed to ai_0114
ai_0113_30	Renamed to ai_0115

# Products
C_FIBR	Moved from agriculture to manufacturing
C_WOOL	Code renamed to 'C_Silk_wool'
C_BKBP	Moved to brown coal products
fi_1104	Removed (duplicate)
C_COIL	Moved from services to mining
fi_12010	Removed (duplicate)
fi_2711_21	Moved to C_GASE as parent
C_Kfert	Moved, because K means potassium not calcium
fi_17300	Removed; excess intermediate level
C_HWAT	Made a child of C_HEAT
C_heat_*	Made children of C_HWAT
fi_18000	Removed; excess intermediate level
fi_0309_10	Removed; Identical to fi_2129
fi_0309_90	Removed; Identical to fi_2129
fi_1602_*	Removed; Links to multiple items under fi_2118; cannot be integrated in the tree, but if you have external data with these codes, you can link them to the most relevant existing code.
fi_1602_50	Removed; Equal to fi_21182
fi_1601_00	Removed; Equal to fi_21184
fi_0309_10	Moved to fi_2123
fi_0309_90	Moved to fi_2123
fi_212	Merged with C_FSHP
fi_2367	Code renamed to C_Candy
C_Meat_homo	Todo: most children have to move.
C_bot_water	Redefined as 'Soft drinks; bottled mineral waters'
C_Tobac	Todo: move from manufacturing to agriculture
fi_3462	Code replaced by C_Pfert
fi_34641	Code replaced by C_NPKfert
fi_34644	Removed; duplicate of C_NP_fert
fi_348	Code renamed to C_RUB
C_PA_OTHE	Moved from waste to waste treatment services

C_POWT	Moved from fi_86311 to fi_69111
C_POWD	Moved from fi_86312 to fi_69112
fi_23_x	Code renamed to 'fi_213_x'
C_EXTO	Moved from ft_122 to fi_99

fi_98	Code renamed to fhp_98
C_TEXT	Moved to fi_27
C_WATR	Moved to fi_18
fi_64-fi_67	Renamed to fi_6_x1-fi_6_x7
C_CHEM	Removed from fi_354
fi_96123	Split into fi_96123 and fi_96124
